% Octave script to visualise the motion of a plucked string
% as the sum of two identical waveforms moving in opposite directions. 
clear all
clc

% initialise variables
n = 1:100;
% length of the string chosen as 100 cm
L = 100;
% plucking position defined as a fraction of the string's length
p = L/9;
% the string is drawn from 0 to L in the x direction
x = 0:0.1:L;
% plucking displacement is chosen as 6mm
a = 0.6;
% drawing the initial configuration at t = 0
t = 0*L;

% calculate the initial shape of the string as
% two identical triangles K1 and K2 and their sum K3
FACTOR = 2*a*(L/p + L/(L-p))/pi^2;
Z1 = sin(n'*pi*(x-t)/L)';
Z2 = sin(n'*pi*(x+t)/L)';
Z = (sin(n*pi*p/L)./n.^2)';
K1 = 0.5*FACTOR*Z1*Z;
K2 = 0.5*FACTOR*Z2*Z;
K3 = K1 + K2;

% setup a figure to the screen, the plot in it will be updated dynamically
figur = plot(x,K3,'LineWidth',5, x,K2,'LineWidth',5, x,K1,'LineWidth',5);
set(gca,'ylim',[-a*1.1 a*1.1]);
set(gca,'ytick',[-a 0 a]);
set(gca,'yticklabel',{'-a','0','a'});
set(gca,'xlim',[0,L]);
set(gca,'xtick',[0 p L]);
set(gca,'xticklabel',{'0','p','L'});
set(gca,'fontsize',14);
legend('a*[f(x-ct) + f(x+ct)]','f(x+ct)','f(x-ct)');

% loop for few full periods of vibration, advance time
for s = 1:400
t = (s/100)*L;

% calculate the shape of the string again as the time has changed
FACTOR = 2*a*(L/p + L/(L-p))/pi^2;
Z1 = sin(n'*pi*(x-t)/L)';
Z2 = sin(n'*pi*(x+t)/L)';
Z = (sin(n*pi*p/L)./n.^2)';
K1 = 0.5*FACTOR*Z1*Z;
K2 = 0.5*FACTOR*Z2*Z;
K3 = K1 + K2;

% update data in the figure window
set(figur(1),'ydata',K3);
set(figur(2),'ydata',K2);
set(figur(3),'ydata',K1);

% draw the updated data
drawnow;
end;

